@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "emms-state" "0.2.1"
+(define-package "emms-state" "20260102.648"
   "Display EMMS track description and playing time in the mode line."
   '((emms "0"))
   :url "https://github.com/alezost/emms-state.el"
